@@ -3,6 +3,10 @@ import os
 from django.forms import widgets
 from django.utils.safestring import mark_safe
 from django.core.urlresolvers import reverse
+from django.conf import settings
+
+
+S3DIRECT_DIR = getattr(settings, 'S3DIRECT_DIR', 's3direct')
 
 
 class S3DirectWidget(widgets.TextInput):
@@ -31,17 +35,17 @@ class S3DirectWidget(widgets.TextInput):
             )
         }
 
-    def __init__(self, upload_to):
-        self.upload_to = upload_to
-        super(S3DirectWidget, self).__init__()
+    def __init__(self, *args, **kwargs):
+        self.upload_to = kwargs.pop('upload_to', None) or S3DIRECT_DIR
+        super(S3DirectWidget, self).__init__(*args, **kwargs)
 
     def render(self, name, value, attrs=None):
         output = self.html.format(
-                policy_url=reverse('s3direct'),
-                element_id=self.build_attrs(attrs).get('id'),
-                file_name=os.path.basename(value or ''),
-                upload_to=self.upload_to,
-                file_url=value or '',
-                name=name)
+            policy_url=reverse('s3direct'),
+            element_id=self.build_attrs(attrs).get('id'),
+            file_name=os.path.basename(value or ''),
+            upload_to=self.upload_to,
+            file_url=value or '',
+            name=name)
 
-        return mark_safe(output)
\ No newline at end of file
+        return mark_safe(output)
